@@ -14,22 +14,22 @@ use SVN::Client;
 use SVN::S4::CatOrMods;
 use SVN::S4::Config;
 use SVN::S4::Debug qw (DEBUG is_debug);
+use SVN::S4::Commit;
 use SVN::S4::FixProp;
 use SVN::S4::Getopt;
 use SVN::S4::Info;
 use SVN::S4::Path;
-use SVN::S4::Update;
-use SVN::S4::ViewSpec;
-use SVN::S4::QuickCommit;
 use SVN::S4::Scrub;
 use SVN::S4::Snapshot;
+use SVN::S4::Update;
+use SVN::S4::ViewSpec;
 use SVN::S4::WorkProp;
 use strict;
 
 ######################################################################
 #### Configuration Section
 
-our $VERSION = '1.055';
+our $VERSION = '1.056';
 
 # SVN::Client methods
 #       $ctx->add($path, $recursive, $pool);
@@ -131,22 +131,34 @@ sub new {
 		#_client => undef,
 		#_pool => undef,
 		_file_in_repo => {},
+		_client_reopens => 30,
 		@_};
+    bless ($self, $class);
     # Copy all environment variables into viewspec_vars. Later the viewspec
     # "set" command will either use them or override them.
     foreach (keys %ENV) {
         $self->{viewspec_vars}->{$_} = $ENV{$_};
     }
-    my %client_params = %{$self};
-    $self->{_client} = new SVN::Client
-	(auth => [SVN::Client::get_simple_provider(),
-	         SVN::Client::get_username_provider()],
-	 %{$self});
+    $self->{_client_params} = [%{$self}];  # Keep list small - self will grow later
+    $self->client_reopen();
     $self->{_pool} = SVN::Pool->new_default;
-    bless ($self, $class);
     return $self;
 }
 
+sub client_reopen {
+    my $self = shift;
+    # SVN has a bug where "svnserve -t" processes will not properly reap on calls
+    # to proplist.  So every so may attempts, close the client and reopen it
+    $self->{_client_reopen_num} ++;
+    if (!$self->{_client} || $self->{_client_reopen_num} > $self->{_client_reopens}) {
+	$self->{_client_reopen_num} = 0;
+	$self->{_client} = new SVN::Client
+	    (auth => [SVN::Client::get_simple_provider(),
+		      SVN::Client::get_username_provider()],
+	     @{$self->{_client_params}});
+    }
+}
+
 sub args_to_params {
     my %args = (@_);
     my %outargs;
@@ -375,6 +387,7 @@ sub file_root {
 	$self->open();
 	my $root;
 	$self->hide_all_output();
+	$self->client_reopen();
 	$self->client->info($filename, undef,
 			    $self->is_file_local(filename=>$filename)?undef:'HEAD',
 			    sub {
@@ -444,6 +457,7 @@ sub is_file_in_repo {
     my $exists = 0;
     eval {
 	# ."" needed to make sure stringification occurs, as SWIG won't do so
+	$self->client_reopen();
 	my $proplist = $self->client->proplist($url, $params{revision}.'', 0);
 	DEBUG "proplist returned, so the url must have existed\n" if $self->debug;
 	$exists = 1;
@@ -485,6 +499,7 @@ sub rev_on_date {
     DEBUG "about to call revprop_list with url=$url rev=$date\n" if $self->debug;
     # Concat with "" makes it into a string, if it's not.
     # gets around TypeError in method 'svn_client_revprop_list', argument 2
+    $self->client_reopen();
     my ($props,$rev) = $self->client->revprop_list($url."", $date, $self->pool);
     if ($rev !~ /[0-9]+/) {
 	die "s4: %Error: failed to look up revision number for '$date'";
@@ -628,6 +643,7 @@ sub propget_string {
     DEBUG "\tsvn_propget $filename  $params{propname}\n" if $self->debug;
 
     $self->open();
+    $self->client_reopen();
     my $pl = $self->client->proplist($filename, undef, 0);
     return undef if !$pl;
     foreach my $propitem (@{$pl}) {
@@ -653,6 +669,7 @@ sub propset_string {
     if (!defined $stored || (($stored ne $params{propval})
 			     && "$stored\n" ne $params{propval})) {
 	print "    svn propset $params{propname} $filename\n" if !$params{quiet};
+	$self->client_reopen();
 	$self->client->propset($params{propname}, $params{propval}, $params{filename}, 0) if !$params{dryrun};
     }
 }
@@ -701,7 +718,7 @@ Create a new SVN::S4 object.
 
 The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 2002-2013 by Wilson Snyder.  This package is free software; you
+Copyright 2002-2015 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
@@ -715,11 +732,11 @@ Wilson Snyder <wsnyder@wsnyder.org>
 L<svn>, L<s4>
 
 L<SVN::Client>,
+L<SVN::S4::Commit>,
 L<SVN::S4::FixProp>,
 L<SVN::S4::Getopt>,
 L<SVN::S4::Info>,
 L<SVN::S4::Path>,
-L<SVN::S4::QuickCommit>,
 L<SVN::S4::Scrub>,
 L<SVN::S4::Snapshot>,
 L<SVN::S4::Update>,
