@@ -12,7 +12,7 @@ use Carp;
 use Config::Tiny;
 use vars qw($AUTOLOAD);
 
-our $VERSION = '1.055';
+our $VERSION = '1.056';
 
 #######################################################################
 #######################################################################
@@ -24,10 +24,11 @@ use SVN::S4::Debug qw (DEBUG is_debug);
 
 sub _config_filenames {
     # Files where config may live
-    our @out = ("/etc/subversion/config", "$ENV{HOME}/.subversion/config");
-    if ($ENV{S4_CONFIG}) {
-	push @out, $ENV{S4_CONFIG};
-    }
+    our @out;
+    push @out, "/etc/subversion/config";
+    push @out, $ENV{S4_CONFIG_SITE} if $ENV{S4_CONFIG_SITE};
+    push @out, "$ENV{HOME}/.subversion/config" if $ENV{HOME};
+    push @out, $ENV{S4_CONFIG} if $ENV{S4_CONFIG};
     return @out;
 }
 
@@ -67,6 +68,24 @@ sub config_get_bool {
     return 0;
 }
 
+sub config_glob_to_regexp {
+    my $self = shift;
+    my $glob = shift;
+    my $re = '(';
+    foreach my $ch (split //, $glob) {
+	if ($ch eq ' ') {
+	    $re .= '|' unless $re =~ /[|]$/;
+	} elsif ($ch eq '*') {
+	    $re .= '.*';
+	} elsif ($ch =~ /[a-z0-9A-Z?]/) {
+	    $re .= $ch;
+	} else {
+	    $re .= "\\".$ch;
+	}
+    }
+    $re .= ')$';
+}
+
 ######################################################################
 ### Package return
 package SVN::S4::Config;
@@ -105,7 +124,7 @@ Return the config value for the given section and key.
 
 The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 2005-2013 by Wilson Snyder.  This package is free software; you
+Copyright 2005-2015 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
