@@ -13,7 +13,7 @@ use Data::Dumper;
 ######################################################################
 #### Configuration Section
 
-our $VERSION = '1.055';
+our $VERSION = '1.056';
 
 our %_Aliases =
     (
@@ -165,7 +165,10 @@ our %_Args =
 	       .' [--config-option ARG]'	# 1.6
 	       .' [PATH...]')},
   'commit'	=> {
+      s4_changed => 1,
       args => (''
+	       .' [--unsafe]'			# S4 addition
+	       #
 	       .' [--changelist ARG]'		# 1.6
 	       .' [--depth ARG]'
 	       .' [--editor-cmd ARG]'		# 1.6
@@ -929,7 +932,10 @@ sub parseCmd {
     my $paramNum = 0;
     my $inFlags = 1;
     foreach my $arg (@args) {
-	if ($inFlags && $arg =~ /^-/) {
+	if ($inSwitch) {   # Argument to a switch
+	    push @out, $inSwitch;
+	    $inSwitch = 0;
+	} elsif ($inFlags && $arg =~ /^-/) {
 	    if ($arg eq "--") {
 		$inFlags = 0;
 	    } elsif ($parser->{$arg}) {
@@ -939,10 +945,7 @@ sub parseCmd {
 		push @out, "unknown";
 	    }
 	} else {
-	    if ($inSwitch) {   # Argument to a switch
-		push @out, $inSwitch;
-		$inSwitch = 0;
-	    } elsif ($parser->{$paramNum}) {  # Named [optional?] argument
+	    if ($parser->{$paramNum}) {  # Named [optional?] argument
 		push @out, $parser->{$paramNum}{what};
 		$paramNum++ if !$parser->{$paramNum}{more};
 	    } else {
@@ -1165,7 +1168,7 @@ Return the option list, with the specified matching argument removed.
 
 The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 2002-2013 by Wilson Snyder.  This package is free software; you
+Copyright 2002-2015 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
