@@ -9,7 +9,7 @@ use strict;
 
 use SVN::S4::Debug qw (DEBUG is_debug);
 
-our $VERSION = '1.055';
+our $VERSION = '1.056';
 
 ######################################################################
 
@@ -78,6 +78,26 @@ sub wholefile {
     return $wholefile;
 }
 
+sub prefetchDirTree {
+    my @dirs = @_;
+    _prefetchDirTreeRecurse("", \@dirs);
+    IO::AIO::flush();
+}
+
+sub _prefetchDirTreeRecurse {
+    my $dir = shift;
+    my $bases = shift;
+    foreach my $base (@{$bases}) {
+	my $file = $dir;
+	$file .= "/" if $file ne "";
+	$file .= $base;
+	if (1) {  # $base ne ".svn"
+	    IO::AIO::aio_scandir($file, 16, sub {
+		_prefetchDirTreeRecurse($file, @_); } );
+	}
+    }
+}
+
 ######################################################################
 ### Package return
 1;
@@ -113,13 +133,18 @@ Return true if the filename is a absolute URL file name.
 
 Return contents of the file as a string, or undef if does not exist.
 
+=item prefetchDirTree($dir)
+
+Use AIO to read directory stat() information into the file cache, so
+subsequent stats() or svn operations will proceed very quickly.
+
 =back
 
 =head1 DISTRIBUTION
 
 The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 2002-2013 by Wilson Snyder.  This package is free software; you
+Copyright 2002-2015 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
