@@ -53,7 +53,7 @@ use SVN::S4;
 use SVN::S4::Debug qw (DEBUG is_debug);
 use SVN::S4::Path;
 
-our $VERSION = '1.055';
+our $VERSION = '1.056';
 our $Info = 1;
 
 
@@ -140,6 +140,8 @@ sub _snapshot_main {
     my $canonical_path = $self->abs_filename($params{path});
     chdir $canonical_path or die "s4: %Error: chdir $canonical_path";
 
+    $self->_snapshot_get_info($canonical_path);
+
     $Snapshot_Statfunc_Debug = $self->debug || 0;
     $self->client->notify(\&_notify_callback);
     my @objects = do_svn_status ($self, $canonical_path, $params{disregard_ignore_list});
@@ -166,7 +168,7 @@ sub _snapshot_main {
 	my $rev = $obj->{revision};
 	if (defined $rev) {
 	    add_dir  ($relpath, $rev, $obj) if $kind eq 'dir';
-	    add_file ($relpath, $rev) if $kind eq 'file';
+	    add_file ($relpath, $rev, $obj) if $kind eq 'file';
 	}
 	# look for property differences
 	if ($ps eq 'normal' || $ps eq 'none') {
@@ -287,14 +289,16 @@ fi
 
     #
     # Do updates of dirs in increasing order of depth.
-    my @sorted_dirs = sort {$a->{depth} cmp $b->{depth}} @Dirs;
+    my @sorted_dirs = sort {$a->{depth} cmp $b->{depth}
+			    || $a->{dirpath} cmp $b->{dirpath}} @Dirs;
     foreach my $dir (@sorted_dirs) {
 	my $dirpath = $dir->{dirpath};
 	#print STDERR "# directory $dirpath\n";
 	my $parent = parent_of_dir($dir);
 	my $extern = $Externals{$dir->{obj}->{path}};  #ask externals hash if it is one
-	my $this_url = $self->get_svn_url($dirpath);
+	my $this_url = $self->get_svn_url($dir->{obj}{path});
 	my $quiet = $self->{quiet} ? "--quiet" : "";
+	my $parent_url = $parent && $self->get_svn_url($parent->{obj}{path});
 	if ($extern) {
 	    print STDOUT "# directory '$dirpath' is an extern\n";
 	    print STDOUT "svn checkout $quiet --revision $dir->{rev} '$this_url' '$dirpath'\n";
@@ -302,7 +306,6 @@ fi
 	    # if this dir has a different rev than its parent, or if its url
 	    # is not what one would expect (svn switch), generate a command
 	    # to recreate that in the new tree.
-	    my $parent_url = $self->get_svn_url($parent->{dirpath});
 	    my $dirpath_last_elem = $dirpath;
 	    $dirpath_last_elem =~ s/.*\///;
 	    my $match_url = "$parent_url/$dirpath_last_elem";
@@ -315,19 +318,29 @@ fi
 	    if ($switched) {
 		DEBUG "this_url=$this_url, expected $parent_url/$dirpath_last_elem\n" if $self->debug;
 		print STDOUT "# directory '$dirpath' url differs from parent\n";
-		print STDOUT "(cd '$dirpath' && \$S4 switch $quiet --revision $dir->{rev} '$this_url')\n";
+		print STDOUT "(cd '$dirpath' && \$S4 --orig switch $quiet --revision $dir->{rev} '$this_url')\n";
 	    } elsif ($revchange) {
 		DEBUG "urls match. thisrev=$dir->{rev}, parent rev=$parent->{rev}\n" if $self->debug;
 		print STDOUT "# directory '$dirpath' revision differs from parent\n";
-		print STDOUT "(cd '$dirpath' && \$S4 up $quiet --revision $dir->{rev})\n";
+		print STDOUT "(cd '$dirpath' && \$S4 --orig up $quiet --revision $dir->{rev})\n";
 	    }
 	}
 	# find files in this directory whose rev differs from the directory
+	$parent_url = $this_url;  # Parent of file is the directory
 	foreach my $file (@{$File_by_dirpath{$dirpath}}) {
 	    #print STDOUT "# file '$file->{filename}' is rev $file->{rev}\n";
-	    if ($file->{rev} != 0 && $dir->{rev} != 0
-		&& ($file->{rev} != $dir->{rev})) {
-		print STDOUT "(cd '$dirpath' && \$S4 up $quiet --revision $file->{rev} '$file->{filename}')\n";
+	    my $filepath = $dirpath."/".$file->{filename};
+	    my $this_url;
+	    $this_url = $self->get_svn_url($file->{obj}{path});
+	    my $dirpath_last_elem = $file->{filename};
+	    $dirpath_last_elem =~ s/.*\///;
+	    my $match_url = "$parent_url/$dirpath_last_elem";
+	    my $switched = $this_url ne $match_url;
+	    if ($switched) {
+		print STDOUT "(cd '$dirpath' && \$S4 --orig switch $quiet --revision $file->{rev} '$this_url' '$file->{filename}')\n";
+	    } elsif ($file->{rev} != 0 && $dir->{rev} != 0
+		     && ($file->{rev} != $dir->{rev})) {
+		print STDOUT "(cd '$dirpath' && \$S4 --orig up $quiet --revision $file->{rev} '$file->{filename}')\n";
 	    }
 	}
     }
@@ -518,21 +531,38 @@ sub get_svn_rev {
     return $rev;
 }
 
-sub get_svn_url {
-    # I don't know how to do this with SVN::Client.
-    # So do it the old fashioned way.
+sub _snapshot_get_info {
     my ($self,$path) = @_;
-    DEBUG "Exec: cd '$path' && $self->{svn_binary} info\n" if $self->debug;
-    open (INFO, "cd '$path' && $self->{svn_binary} info |");
-    my $url;
-    while (<INFO>) {
-	if (/^URL: (.*)/) {
-	    $url = $1;
-	    #last;  # Causes broken pipe
-	}
+    $self->{_snapshot_infos} = {};
+    $path = SVN::S4::Path::fileNoLinks($path);
+    my $pathre = quotemeta($path);
+    $pathre = qr!$pathre!;
+    my $stat = $self->client->info
+	($path,			# canonical path
+	 undef,			# peg_revision
+	 undef,			# revision - NULL means don't contact server
+	 sub {
+	     my ($path, $info, $pool) = @_;
+	     my $relpath = $path;
+	     # Keeping the whole object around causes a core dump, so pick what we need
+	     $self->{_snapshot_infos}{$relpath} = {
+		 URL => $info->URL,
+	     };
+	     #DEBUG "get_info ADD $relpath\n"; # if $self->debug;
+	 }, # status func
+	 1,			# recursive
+	 );
+}
+
+sub get_svn_url {
+    my ($self,$path) = @_;
+    my $rtn = $self->{_snapshot_infos}{$path};
+    #DEBUG "get_svn_url $path  GG $rtn\n";  # if $self->debug;
+    if ($rtn && $rtn->{URL}) {
+	return $rtn->{URL};
+    } else {
+	return undef;
     }
-    close INFO;
-    return $url;
 }
 
 sub add_dir {
@@ -547,7 +577,7 @@ sub add_dir {
 }
 
 sub add_file {
-    my ($path, $rev) = @_;
+    my ($path, $rev, $obj) = @_;
     my $dirpath;
     my $filename;
     if ($path =~ /^(.*)\/([^\/]+)$/) {
@@ -555,7 +585,7 @@ sub add_file {
     } else {
         ($dirpath,$filename) = ('.', $path);
     }
-    my $file = {filename=>$filename, rev=>$rev};
+    my $file = {filename=>$filename, rev=>$rev, obj=>$obj};
     push @{$File_by_dirpath{$dirpath}}, $file;
     #DEBUG "File_by_dirpath{$dirpath} = $filename\n";  # if $self->debug;
 }
@@ -692,7 +722,7 @@ SVN::S4::Snapshot
 
 The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 2005-2011 by Bryce Denney.  This package is free software; you
+Copyright 2005-2013 by Bryce Denney.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
