@@ -16,7 +16,7 @@ use SVN::S4;
 use SVN::S4::Debug qw (DEBUG is_debug);
 use SVN::S4::Path;
 
-our $VERSION = '1.055';
+our $VERSION = '1.056';
 our $Info = 1;
 
 
@@ -352,7 +352,7 @@ sub apply_viewspec {
 	    $base_uuid = $self->client->uuid_from_url ($base_url);
 	    DEBUG "Base repository UUID is $base_uuid\n" if $self->debug;
 	}
-	my $cmd = "";
+
 	if ($action->{cmd} eq 'switch') {
 	    my $reldir = $action->{dir};
 	    push @{$self->{viewspec_managed_switches}}, $reldir;
@@ -372,9 +372,12 @@ sub apply_viewspec {
 	    my $verb;
 	    my $cleandir = $self->clean_filename("$params{path}/$reldir");
 	    if ($url && $url eq $action->{url}) {
-		$cmd = "$self->{svn_binary} update $cleandir -r$rev";
+		my $cmd = "$self->{svn_binary} update $cleandir -r$rev";
 		$cmd .= ' --quiet' if $self->quiet;
-		$verb = "Updating";
+		if (!$self->quiet) {
+		    print "s4: Updating $reldir\n";
+		}
+		$self->run ($cmd);
 	    } else {
 		if (!$self->is_file_in_repo(url=>$action->{url}, revision=>$rev)) {
 		    die "s4: %Error: Cannot switch to nonexistent URL: $action->{url}";
@@ -384,24 +387,21 @@ sub apply_viewspec {
 		if ($uuid ne $base_uuid) {
 		    die "s4: %Error: URL $action->{url} is in a different repository! What you need is an SVN external, which viewspecs presently do not support.";
 		}
-		$cmd = "$self->{svn_binary} switch $action->{url} $cleandir -r$rev";
+		my $cmd = "$self->{svn_binary} switch $action->{url} $cleandir -r$rev";
 		$cmd .= ' --quiet' if $self->quiet;
-		$verb = "Switching";
-	    }
-	    if (!$self->quiet) {
-		print "s4: $verb $reldir";
-		if ($verb eq 'Switching') {
+		if (!$self->quiet) {
+		    print "s4: Switching $reldir";
 		    my $rootre = quotemeta($self->file_root(path=>$action->{url}));
 		    (my $showurl = $action->{url}) =~ s/$rootre/^/;
 		    print " to $showurl";
 		    print " rev $rev" if $rev ne 'HEAD';
+		    print "\n";
 		}
-		print "\n";
+		$self->run ($cmd);
 	    }
 	} else {
 	    die "s4: %Error: unknown s4 viewspec command: $action\n";
 	}
-	$self->run ($cmd);
     }
     # Look for any switch points that S4 __used to__ maintain, but no longer does.
     # Undo those switch points, if possible.
@@ -658,7 +658,7 @@ is to run svn switch on the Foo directory the the URL Bar at revision 50.
 
 The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 2005-2011 by Bryce Denney.  This package is free software; you
+Copyright 2005-2013 by Bryce Denney.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
