@@ -1,6 +1,6 @@
 # DESCRIPTION: Perl ExtUtils: Common routines required by package tests
 #
-# Copyright 2002-2013 by Wilson Snyder.  This program is free software;
+# Copyright 2002-2015 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
@@ -25,6 +25,7 @@ if (!$ENV{HARNESS_ACTIVE}) {
     use lib '..';
     use lib "blib/lib";
     use lib "blib/arch";
+    use lib "lib";
 }
 
 sub run_system {
@@ -104,4 +105,12 @@ sub is_cmd ($$) {
     $tb->is_eq($out, $regexp, $tell_cmd);
 }
 
+sub touch ($$) {
+    my $filename = shift;
+    my $contents = shift;
+    my $fh = IO::File->new(">$filename") or die "%Error: $! writing $filename,";
+    $fh->print($contents);
+    $fh->close;
+}
+
 1;
